@@ -6,8 +6,8 @@
 ;; Homepage: https://github.com/emacscollective/no-littering
 ;; Keywords: convenience
 
-;; Package-Version: 20260205.1529
-;; Package-Revision: ec8b6b76e6a8
+;; Package-Version: 20260301.1315
+;; Package-Revision: 3b1d39d6b37f
 ;; Package-Requires: (
 ;;     (emacs  "26.1")
 ;;     (compat "30.1"))
@@ -307,10 +307,12 @@ This variable has to be set before `no-littering' is loaded.")
     (setq lsp-session-file                 (var "lsp/session.el"))
     (setq magithub-cache-file              (var "magithub/cache.el"))
     (setq magithub-dir                     (var "magithub/"))
+    (setq mason-dir                        (var "mason/"))
     (setq mastodon-client--token-file      (var "mastodon-client--token"))
     (setq mc/list-file                     (var "mc-list.el"))
     (setq meghanada-server-install-dir     (var "meghanada/"))
     (setq multi-compile-history-file       (var "multi-compile-history.el"))
+    (setq neocaml-repl-history-file        (var "neocaml-repl-history"))
     (setq nix-buffer-directory-name        (var "nix-buffer/"))
     (setq nomad-tramp-script-directory     (var "nomad-tramp/"))
     ;; The value of this variable MUST NOT end with ".el" but the
